/**
 * File: Robojax_SevenSegmentClock.h
 Written by Ahmad Shamshiri (Robojax.com) on July 25, 2019
 
 Version 1.0 July 27, 2019

 * Description:
 * Robojax_SevenSegmentClock is an Arduino library for displaying analog values in LCD display, 
 *   which is previously initialized. This library uses LCD library (https://bitbucket.org/fmalpartida/new-liquidcrystal/wiki/Home) for displaying.
 *
 * Author: Ahmad Shamshiri
 * Contact: Robojax.com contact page
 * Copyright: 2019 Ahmad Shamshiri
 * Copying permission statement:
    This file is part of Robojax_SevenSegmentClock.

    Robojax_SevenSegmentClock is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.

*/

#ifndef LEDCLOCK_H
#define LEDCLOCK_H

#include <Robojax_SevenSegmentClock.h>

#include "Arduino.h"

class Robojax_SevenSegmentClock
{
public:
    /**
     * Create an instance of the class. 
	 A, B, C, C, E, F, G are segments of 7-segment display
	 
     */
    Robojax_SevenSegmentClock(int segments[], int digits[], int colon, int type);
    /**
     * display the time
	 the time is passed as array with 3 element index 0 = hour, 1=minutes and 2=seconds
     */
    void displayTime(int hour, int minute);
   /**
    * Initializes the display.
    */
   void begin();
   
   /*
   * writes the digit
   */
   void writeDigit(int digit, int number); 


 
  /*
  *clears all digits from previous values
  */   
   void clearAllDigits();
   
   void digitOn(int digit);
   void colonBlink();
  /*
  *clears specific digit from previous values
  */  
   void digitOff(int digit);	
private:

    int _type;
	int convertHighLow(int v);
	int _pinDigits[4];
	int _pinSegments[7];
	int _pinColon;
	int debug=0;
	int _blinkTime = 500;// 500 millisecond
	int _rememBlinkTime=0;
	int _blinkStatus=0;



};

#endif //LEDCLOCK
